--- page_type: notification portal_name: Wachstumswende portal_url: https://wachstumswende.de/ portal_image_url: /assets/img/logo.png addressee: Vincent topic: Tom Tomson has accepted the invitation to join your team. prefs_url: /prefs notification_reason: You are getting this notification because [notification reason]. origin_name: Interested civilians origin_url: /groups/interested-civilians origin_image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/group/c6a50692c282d44f4fdf6437d9298765926a212f.png.200x200_q85_crop-1_upscale-1.png notification_body: > Tom Tomson received your invitation and was initially extremely hesistant about the whole thing. The thing is, Tom had already heard about Interested civilians and it gave rose to all sorts of envious internal gnashings, because it just sounded way too close to his budding 'awfully upright citizens 2.0' group. But late last night he came around after 2.5 minutes in the sensory depravation tank, and now he's on board. notification_object: type: event event_text: Tom Tomson joined the group event_meta: Vor 5 Minuten object_name: Interested civilians object_url: /objects/how-to-deal image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/f02dbe79dc5860d041c5483eda5d67a32bd0a6c2.png.263x263_q85_crop-1_upscale-1.jpg --- {{> notification }}